﻿using System;
using System.Collections.Generic;
using Ektron.Cms.API;
using SiteSlider; 

namespace Ektron.Site.Widgets
{
    public partial class Slider : System.Web.UI.UserControl
    {
        #region members
        private int slideSpeed = 2500; //In MS changes to adjust the speed of the rotation
        #endregion

        public string SlideSpeed
        {
            get
            {
                return this.slideSpeed.ToString(); 
            }
        }

        #region Events
        protected void Page_Init(object sender, EventArgs e)
        {
            
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            //Fill CB with SmartFormData//
            uxBannerContentBlock.DefaultContentID = 37;//Set to id of content item using the smart form 
            uxBannerContentBlock.Fill();
            string xml = uxBannerContentBlock.EkItem.Html;
            SiteSlider.GroupBox groupBox = (SiteSlider.GroupBox)Ektron.Cms.EkXml.Deserialize(typeof(SiteSlider.GroupBox), xml);
           
            if (ValidateSlides(groupBox))
            {
                uxSliderMultiView.SetActiveView(slidesView);
                if (!string.IsNullOrEmpty(groupBox.SlideSpeed))
                {
                    int.TryParse(groupBox.SlideSpeed, out slideSpeed); //ms
                }
                List<BannerSlide> slides = GetBannerSlides(groupBox.Slides);
                //DataBind//
                uxBannerRepeater.DataSource = slides;
                uxBannerRepeater.DataBind();
                
            }
            else
            {
                uxSliderMultiView.SetActiveView(noSlidesView);
            }

            RegisterJS();
            RegisterCSS();
        }
        #endregion

        #region helpers

        private bool ValidateSlides(SiteSlider.GroupBox groupBox)
        {
            if (Object.ReferenceEquals(groupBox, null))
            {
                return false;
            }

            foreach (GroupBoxSlides slide in groupBox.Slides)
            {
                if (slide.Image.img == null)
                {
                    return false;
                }
                if (string.IsNullOrEmpty(slide.Image.img.src))
                {
                    return false;
                }
            }
            return true;
        }

        protected void RegisterJS() 
        {
            JS.RegisterJSInclude(this, JS.ManagedScript.EktronJS);
            JS.RegisterJSInclude(this, Ektron.Site.SiteData.Current.Cms.SitePath + "widgets/Site-Slider/bxSlider/ektron.bxslider2.0.1.js", "EktronBxSliderJS");
            JS.RegisterJSInclude(this, Ektron.Site.SiteData.Current.Cms.SitePath + "widgets/Site-Slider/ektron.site.slider.js", "EktronSiteSliderJS");
        }

        protected void RegisterCSS()
        {
            Css.RegisterCss(this, Ektron.Site.SiteData.Current.Cms.SitePath + "widgets/Site-Slider/ektron.site.slider.css", "EktronSiteSliderCSS");
            Css.RegisterCss(this, Ektron.Site.SiteData.Current.Cms.SitePath + "widgets/Site-Slider/ektron.site.slider.ie6.css", "EktronSiteSliderIe6CSS", Css.BrowserTarget.LessThanEqualToIE6);
        }

        protected List<BannerSlide> GetBannerSlides(GroupBoxSlides[] groupBoxSlides)
        {
            List<BannerSlide> bSlides = new List<BannerSlide>();
            foreach (GroupBoxSlides gbSlide in groupBoxSlides)
            {
                string bannerSlideSummary = string.Empty;
                string bannerLinkText = string.Empty;
                string bannerLinkHref = string.Empty;

                if (gbSlide.Summary.Any != null)
                {
                    bannerSlideSummary = gbSlide.Summary.Any[0].InnerText;
                }

                if (gbSlide.Link.a != null)
                {
                    bannerLinkText = gbSlide.Link.a.Any[0].InnerText;
                    bannerLinkHref = gbSlide.Link.a.href;
                }

                bSlides.Add(new BannerSlide(gbSlide.Image.img.src, gbSlide.Title, bannerSlideSummary, bannerLinkText, bannerLinkHref));
            }
            return bSlides;
        }
        #endregion
    }

    public class BannerSlide
    {
        //properties//
        public string SlideImage { get; set; }
        public string Title { get; set; }
        public string Summary { get; set; }
        public string LinkText { get; set; }
        public string LinkUrl { get; set; }

        //constructor//
        public BannerSlide(string slideImage, string title, string summary, string linkText, string linkUrl)
        {
            SlideImage = slideImage;
            Title = title;
            Summary = summary;
            LinkText = linkText;
            LinkUrl = linkUrl;
        }
    }
}


